# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: state.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='state.proto',
  package='io.casperlabs.casper.consensus.state',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0bstate.proto\x12$io.casperlabs.casper.consensus.state\"\xf8\x04\n\x05Value\x12\x13\n\tint_value\x18\x01 \x01(\x05H\x00\x12\x15\n\x0b\x62ytes_value\x18\x02 \x01(\x0cH\x00\x12\x41\n\x08int_list\x18\x03 \x01(\x0b\x32-.io.casperlabs.casper.consensus.state.IntListH\x00\x12\x16\n\x0cstring_value\x18\x04 \x01(\tH\x00\x12@\n\x07\x61\x63\x63ount\x18\x05 \x01(\x0b\x32-.io.casperlabs.casper.consensus.state.AccountH\x00\x12\x42\n\x08\x63ontract\x18\x06 \x01(\x0b\x32..io.casperlabs.casper.consensus.state.ContractH\x00\x12G\n\x0bstring_list\x18\x07 \x01(\x0b\x32\x30.io.casperlabs.casper.consensus.state.StringListH\x00\x12\x43\n\tnamed_key\x18\x08 \x01(\x0b\x32..io.casperlabs.casper.consensus.state.NamedKeyH\x00\x12?\n\x07\x62ig_int\x18\t \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.BigIntH\x00\x12\x38\n\x03key\x18\n \x01(\x0b\x32).io.casperlabs.casper.consensus.state.KeyH\x00\x12:\n\x04unit\x18\x0b \x01(\x0b\x32*.io.casperlabs.casper.consensus.state.UnitH\x00\x12\x14\n\nlong_value\x18\x0c \x01(\x04H\x00\x42\x07\n\x05value\"\x19\n\x07IntList\x12\x0e\n\x06values\x18\x01 \x03(\x05\"\x1c\n\nStringList\x12\x0e\n\x06values\x18\x01 \x03(\t\"*\n\x06\x42igInt\x12\r\n\x05value\x18\x01 \x01(\t\x12\x11\n\tbit_width\x18\x02 \x01(\r\"\xc6\x04\n\x03Key\x12\x44\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x31.io.casperlabs.casper.consensus.state.Key.AddressH\x00\x12>\n\x04hash\x18\x02 \x01(\x0b\x32..io.casperlabs.casper.consensus.state.Key.HashH\x00\x12>\n\x04uref\x18\x03 \x01(\x0b\x32..io.casperlabs.casper.consensus.state.Key.URefH\x00\x12@\n\x05local\x18\x04 \x01(\x0b\x32/.io.casperlabs.casper.consensus.state.Key.LocalH\x00\x1a\x1a\n\x07\x41\x64\x64ress\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0c\x1a\x14\n\x04Hash\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x1a\xe4\x01\n\x04URef\x12\x0c\n\x04uref\x18\x01 \x01(\x0c\x12R\n\raccess_rights\x18\x02 \x01(\x0e\x32;.io.casperlabs.casper.consensus.state.Key.URef.AccessRights\"z\n\x0c\x41\x63\x63\x65ssRights\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04READ\x10\x01\x12\t\n\x05WRITE\x10\x02\x12\x07\n\x03\x41\x44\x44\x10\x04\x12\x0c\n\x08READ_ADD\x10\x05\x12\x0e\n\nREAD_WRITE\x10\x03\x12\r\n\tADD_WRITE\x10\x06\x12\x12\n\x0eREAD_ADD_WRITE\x10\x07\x1a\x15\n\x05Local\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x42\x07\n\x05value\"P\n\x08NamedKey\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x36\n\x03key\x18\x02 \x01(\x0b\x32).io.casperlabs.casper.consensus.state.Key\"\xad\x01\n\x08\x43ontract\x12\x0c\n\x04\x62ody\x18\x01 \x01(\x0c\x12\x42\n\nnamed_keys\x18\x02 \x03(\x0b\x32..io.casperlabs.casper.consensus.state.NamedKey\x12O\n\x10protocol_version\x18\x03 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.state.ProtocolVersion\"\xb0\x05\n\x07\x41\x63\x63ount\x12\x12\n\npublic_key\x18\x01 \x01(\x0c\x12@\n\x08purse_id\x18\x03 \x01(\x0b\x32..io.casperlabs.casper.consensus.state.Key.URef\x12\x42\n\nnamed_keys\x18\x04 \x03(\x0b\x32..io.casperlabs.casper.consensus.state.NamedKey\x12T\n\x0f\x61ssociated_keys\x18\x05 \x03(\x0b\x32;.io.casperlabs.casper.consensus.state.Account.AssociatedKey\x12Y\n\x11\x61\x63tion_thresholds\x18\x06 \x01(\x0b\x32>.io.casperlabs.casper.consensus.state.Account.ActionThresholds\x12W\n\x10\x61\x63\x63ount_activity\x18\x07 \x01(\x0b\x32=.io.casperlabs.casper.consensus.state.Account.AccountActivity\x1a\x33\n\rAssociatedKey\x12\x12\n\npublic_key\x18\x01 \x01(\x0c\x12\x0e\n\x06weight\x18\x02 \x01(\r\x1aR\n\x10\x41\x63tionThresholds\x12\x1c\n\x14\x64\x65ployment_threshold\x18\x01 \x01(\r\x12 \n\x18key_management_threshold\x18\x02 \x01(\r\x1ar\n\x0f\x41\x63\x63ountActivity\x12 \n\x18key_management_last_used\x18\x01 \x01(\x04\x12\x1c\n\x14\x64\x65ployment_last_used\x18\x02 \x01(\x04\x12\x1f\n\x17inactivity_period_limit\x18\x03 \x01(\x04J\x04\x08\x02\x10\x03\"\x06\n\x04Unit\">\n\x0fProtocolVersion\x12\r\n\x05major\x18\x01 \x01(\r\x12\r\n\x05minor\x18\x02 \x01(\r\x12\r\n\x05patch\x18\x03 \x01(\rb\x06proto3')
)



_KEY_UREF_ACCESSRIGHTS = _descriptor.EnumDescriptor(
  name='AccessRights',
  full_name='io.casperlabs.casper.consensus.state.Key.URef.AccessRights',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READ', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WRITE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADD', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READ_ADD', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READ_WRITE', index=5, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADD_WRITE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READ_ADD_WRITE', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1218,
  serialized_end=1340,
)
_sym_db.RegisterEnumDescriptor(_KEY_UREF_ACCESSRIGHTS)


_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='io.casperlabs.casper.consensus.state.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='int_value', full_name='io.casperlabs.casper.consensus.state.Value.int_value', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_value', full_name='io.casperlabs.casper.consensus.state.Value.bytes_value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int_list', full_name='io.casperlabs.casper.consensus.state.Value.int_list', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='io.casperlabs.casper.consensus.state.Value.string_value', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account', full_name='io.casperlabs.casper.consensus.state.Value.account', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contract', full_name='io.casperlabs.casper.consensus.state.Value.contract', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_list', full_name='io.casperlabs.casper.consensus.state.Value.string_list', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='named_key', full_name='io.casperlabs.casper.consensus.state.Value.named_key', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='big_int', full_name='io.casperlabs.casper.consensus.state.Value.big_int', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='io.casperlabs.casper.consensus.state.Value.key', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unit', full_name='io.casperlabs.casper.consensus.state.Value.unit', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_value', full_name='io.casperlabs.casper.consensus.state.Value.long_value', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.state.Value.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=54,
  serialized_end=686,
)


_INTLIST = _descriptor.Descriptor(
  name='IntList',
  full_name='io.casperlabs.casper.consensus.state.IntList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='io.casperlabs.casper.consensus.state.IntList.values', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=688,
  serialized_end=713,
)


_STRINGLIST = _descriptor.Descriptor(
  name='StringList',
  full_name='io.casperlabs.casper.consensus.state.StringList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='io.casperlabs.casper.consensus.state.StringList.values', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=715,
  serialized_end=743,
)


_BIGINT = _descriptor.Descriptor(
  name='BigInt',
  full_name='io.casperlabs.casper.consensus.state.BigInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.state.BigInt.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bit_width', full_name='io.casperlabs.casper.consensus.state.BigInt.bit_width', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=745,
  serialized_end=787,
)


_KEY_ADDRESS = _descriptor.Descriptor(
  name='Address',
  full_name='io.casperlabs.casper.consensus.state.Key.Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='io.casperlabs.casper.consensus.state.Key.Address.account', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1061,
  serialized_end=1087,
)

_KEY_HASH = _descriptor.Descriptor(
  name='Hash',
  full_name='io.casperlabs.casper.consensus.state.Key.Hash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='io.casperlabs.casper.consensus.state.Key.Hash.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1089,
  serialized_end=1109,
)

_KEY_UREF = _descriptor.Descriptor(
  name='URef',
  full_name='io.casperlabs.casper.consensus.state.Key.URef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uref', full_name='io.casperlabs.casper.consensus.state.Key.URef.uref', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='access_rights', full_name='io.casperlabs.casper.consensus.state.Key.URef.access_rights', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _KEY_UREF_ACCESSRIGHTS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1112,
  serialized_end=1340,
)

_KEY_LOCAL = _descriptor.Descriptor(
  name='Local',
  full_name='io.casperlabs.casper.consensus.state.Key.Local',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='io.casperlabs.casper.consensus.state.Key.Local.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1342,
  serialized_end=1363,
)

_KEY = _descriptor.Descriptor(
  name='Key',
  full_name='io.casperlabs.casper.consensus.state.Key',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='io.casperlabs.casper.consensus.state.Key.address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='io.casperlabs.casper.consensus.state.Key.hash', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uref', full_name='io.casperlabs.casper.consensus.state.Key.uref', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local', full_name='io.casperlabs.casper.consensus.state.Key.local', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_KEY_ADDRESS, _KEY_HASH, _KEY_UREF, _KEY_LOCAL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.state.Key.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=790,
  serialized_end=1372,
)


_NAMEDKEY = _descriptor.Descriptor(
  name='NamedKey',
  full_name='io.casperlabs.casper.consensus.state.NamedKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='io.casperlabs.casper.consensus.state.NamedKey.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='io.casperlabs.casper.consensus.state.NamedKey.key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1374,
  serialized_end=1454,
)


_CONTRACT = _descriptor.Descriptor(
  name='Contract',
  full_name='io.casperlabs.casper.consensus.state.Contract',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='body', full_name='io.casperlabs.casper.consensus.state.Contract.body', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='named_keys', full_name='io.casperlabs.casper.consensus.state.Contract.named_keys', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='io.casperlabs.casper.consensus.state.Contract.protocol_version', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1457,
  serialized_end=1630,
)


_ACCOUNT_ASSOCIATEDKEY = _descriptor.Descriptor(
  name='AssociatedKey',
  full_name='io.casperlabs.casper.consensus.state.Account.AssociatedKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='public_key', full_name='io.casperlabs.casper.consensus.state.Account.AssociatedKey.public_key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weight', full_name='io.casperlabs.casper.consensus.state.Account.AssociatedKey.weight', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2064,
  serialized_end=2115,
)

_ACCOUNT_ACTIONTHRESHOLDS = _descriptor.Descriptor(
  name='ActionThresholds',
  full_name='io.casperlabs.casper.consensus.state.Account.ActionThresholds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deployment_threshold', full_name='io.casperlabs.casper.consensus.state.Account.ActionThresholds.deployment_threshold', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key_management_threshold', full_name='io.casperlabs.casper.consensus.state.Account.ActionThresholds.key_management_threshold', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2117,
  serialized_end=2199,
)

_ACCOUNT_ACCOUNTACTIVITY = _descriptor.Descriptor(
  name='AccountActivity',
  full_name='io.casperlabs.casper.consensus.state.Account.AccountActivity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_management_last_used', full_name='io.casperlabs.casper.consensus.state.Account.AccountActivity.key_management_last_used', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deployment_last_used', full_name='io.casperlabs.casper.consensus.state.Account.AccountActivity.deployment_last_used', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inactivity_period_limit', full_name='io.casperlabs.casper.consensus.state.Account.AccountActivity.inactivity_period_limit', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2201,
  serialized_end=2315,
)

_ACCOUNT = _descriptor.Descriptor(
  name='Account',
  full_name='io.casperlabs.casper.consensus.state.Account',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='public_key', full_name='io.casperlabs.casper.consensus.state.Account.public_key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='purse_id', full_name='io.casperlabs.casper.consensus.state.Account.purse_id', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='named_keys', full_name='io.casperlabs.casper.consensus.state.Account.named_keys', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='associated_keys', full_name='io.casperlabs.casper.consensus.state.Account.associated_keys', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_thresholds', full_name='io.casperlabs.casper.consensus.state.Account.action_thresholds', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_activity', full_name='io.casperlabs.casper.consensus.state.Account.account_activity', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ACCOUNT_ASSOCIATEDKEY, _ACCOUNT_ACTIONTHRESHOLDS, _ACCOUNT_ACCOUNTACTIVITY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1633,
  serialized_end=2321,
)


_UNIT = _descriptor.Descriptor(
  name='Unit',
  full_name='io.casperlabs.casper.consensus.state.Unit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2323,
  serialized_end=2329,
)


_PROTOCOLVERSION = _descriptor.Descriptor(
  name='ProtocolVersion',
  full_name='io.casperlabs.casper.consensus.state.ProtocolVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='major', full_name='io.casperlabs.casper.consensus.state.ProtocolVersion.major', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minor', full_name='io.casperlabs.casper.consensus.state.ProtocolVersion.minor', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='patch', full_name='io.casperlabs.casper.consensus.state.ProtocolVersion.patch', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2331,
  serialized_end=2393,
)

_VALUE.fields_by_name['int_list'].message_type = _INTLIST
_VALUE.fields_by_name['account'].message_type = _ACCOUNT
_VALUE.fields_by_name['contract'].message_type = _CONTRACT
_VALUE.fields_by_name['string_list'].message_type = _STRINGLIST
_VALUE.fields_by_name['named_key'].message_type = _NAMEDKEY
_VALUE.fields_by_name['big_int'].message_type = _BIGINT
_VALUE.fields_by_name['key'].message_type = _KEY
_VALUE.fields_by_name['unit'].message_type = _UNIT
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['int_value'])
_VALUE.fields_by_name['int_value'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['bytes_value'])
_VALUE.fields_by_name['bytes_value'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['int_list'])
_VALUE.fields_by_name['int_list'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['string_value'])
_VALUE.fields_by_name['string_value'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['account'])
_VALUE.fields_by_name['account'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['contract'])
_VALUE.fields_by_name['contract'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['string_list'])
_VALUE.fields_by_name['string_list'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['named_key'])
_VALUE.fields_by_name['named_key'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['big_int'])
_VALUE.fields_by_name['big_int'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['key'])
_VALUE.fields_by_name['key'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['unit'])
_VALUE.fields_by_name['unit'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['long_value'])
_VALUE.fields_by_name['long_value'].containing_oneof = _VALUE.oneofs_by_name['value']
_KEY_ADDRESS.containing_type = _KEY
_KEY_HASH.containing_type = _KEY
_KEY_UREF.fields_by_name['access_rights'].enum_type = _KEY_UREF_ACCESSRIGHTS
_KEY_UREF.containing_type = _KEY
_KEY_UREF_ACCESSRIGHTS.containing_type = _KEY_UREF
_KEY_LOCAL.containing_type = _KEY
_KEY.fields_by_name['address'].message_type = _KEY_ADDRESS
_KEY.fields_by_name['hash'].message_type = _KEY_HASH
_KEY.fields_by_name['uref'].message_type = _KEY_UREF
_KEY.fields_by_name['local'].message_type = _KEY_LOCAL
_KEY.oneofs_by_name['value'].fields.append(
  _KEY.fields_by_name['address'])
_KEY.fields_by_name['address'].containing_oneof = _KEY.oneofs_by_name['value']
_KEY.oneofs_by_name['value'].fields.append(
  _KEY.fields_by_name['hash'])
_KEY.fields_by_name['hash'].containing_oneof = _KEY.oneofs_by_name['value']
_KEY.oneofs_by_name['value'].fields.append(
  _KEY.fields_by_name['uref'])
_KEY.fields_by_name['uref'].containing_oneof = _KEY.oneofs_by_name['value']
_KEY.oneofs_by_name['value'].fields.append(
  _KEY.fields_by_name['local'])
_KEY.fields_by_name['local'].containing_oneof = _KEY.oneofs_by_name['value']
_NAMEDKEY.fields_by_name['key'].message_type = _KEY
_CONTRACT.fields_by_name['named_keys'].message_type = _NAMEDKEY
_CONTRACT.fields_by_name['protocol_version'].message_type = _PROTOCOLVERSION
_ACCOUNT_ASSOCIATEDKEY.containing_type = _ACCOUNT
_ACCOUNT_ACTIONTHRESHOLDS.containing_type = _ACCOUNT
_ACCOUNT_ACCOUNTACTIVITY.containing_type = _ACCOUNT
_ACCOUNT.fields_by_name['purse_id'].message_type = _KEY_UREF
_ACCOUNT.fields_by_name['named_keys'].message_type = _NAMEDKEY
_ACCOUNT.fields_by_name['associated_keys'].message_type = _ACCOUNT_ASSOCIATEDKEY
_ACCOUNT.fields_by_name['action_thresholds'].message_type = _ACCOUNT_ACTIONTHRESHOLDS
_ACCOUNT.fields_by_name['account_activity'].message_type = _ACCOUNT_ACCOUNTACTIVITY
DESCRIPTOR.message_types_by_name['Value'] = _VALUE
DESCRIPTOR.message_types_by_name['IntList'] = _INTLIST
DESCRIPTOR.message_types_by_name['StringList'] = _STRINGLIST
DESCRIPTOR.message_types_by_name['BigInt'] = _BIGINT
DESCRIPTOR.message_types_by_name['Key'] = _KEY
DESCRIPTOR.message_types_by_name['NamedKey'] = _NAMEDKEY
DESCRIPTOR.message_types_by_name['Contract'] = _CONTRACT
DESCRIPTOR.message_types_by_name['Account'] = _ACCOUNT
DESCRIPTOR.message_types_by_name['Unit'] = _UNIT
DESCRIPTOR.message_types_by_name['ProtocolVersion'] = _PROTOCOLVERSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), {
  'DESCRIPTOR' : _VALUE,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Value)
  })
_sym_db.RegisterMessage(Value)

IntList = _reflection.GeneratedProtocolMessageType('IntList', (_message.Message,), {
  'DESCRIPTOR' : _INTLIST,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.IntList)
  })
_sym_db.RegisterMessage(IntList)

StringList = _reflection.GeneratedProtocolMessageType('StringList', (_message.Message,), {
  'DESCRIPTOR' : _STRINGLIST,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.StringList)
  })
_sym_db.RegisterMessage(StringList)

BigInt = _reflection.GeneratedProtocolMessageType('BigInt', (_message.Message,), {
  'DESCRIPTOR' : _BIGINT,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.BigInt)
  })
_sym_db.RegisterMessage(BigInt)

Key = _reflection.GeneratedProtocolMessageType('Key', (_message.Message,), {

  'Address' : _reflection.GeneratedProtocolMessageType('Address', (_message.Message,), {
    'DESCRIPTOR' : _KEY_ADDRESS,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Key.Address)
    })
  ,

  'Hash' : _reflection.GeneratedProtocolMessageType('Hash', (_message.Message,), {
    'DESCRIPTOR' : _KEY_HASH,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Key.Hash)
    })
  ,

  'URef' : _reflection.GeneratedProtocolMessageType('URef', (_message.Message,), {
    'DESCRIPTOR' : _KEY_UREF,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Key.URef)
    })
  ,

  'Local' : _reflection.GeneratedProtocolMessageType('Local', (_message.Message,), {
    'DESCRIPTOR' : _KEY_LOCAL,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Key.Local)
    })
  ,
  'DESCRIPTOR' : _KEY,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Key)
  })
_sym_db.RegisterMessage(Key)
_sym_db.RegisterMessage(Key.Address)
_sym_db.RegisterMessage(Key.Hash)
_sym_db.RegisterMessage(Key.URef)
_sym_db.RegisterMessage(Key.Local)

NamedKey = _reflection.GeneratedProtocolMessageType('NamedKey', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDKEY,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.NamedKey)
  })
_sym_db.RegisterMessage(NamedKey)

Contract = _reflection.GeneratedProtocolMessageType('Contract', (_message.Message,), {
  'DESCRIPTOR' : _CONTRACT,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Contract)
  })
_sym_db.RegisterMessage(Contract)

Account = _reflection.GeneratedProtocolMessageType('Account', (_message.Message,), {

  'AssociatedKey' : _reflection.GeneratedProtocolMessageType('AssociatedKey', (_message.Message,), {
    'DESCRIPTOR' : _ACCOUNT_ASSOCIATEDKEY,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Account.AssociatedKey)
    })
  ,

  'ActionThresholds' : _reflection.GeneratedProtocolMessageType('ActionThresholds', (_message.Message,), {
    'DESCRIPTOR' : _ACCOUNT_ACTIONTHRESHOLDS,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Account.ActionThresholds)
    })
  ,

  'AccountActivity' : _reflection.GeneratedProtocolMessageType('AccountActivity', (_message.Message,), {
    'DESCRIPTOR' : _ACCOUNT_ACCOUNTACTIVITY,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Account.AccountActivity)
    })
  ,
  'DESCRIPTOR' : _ACCOUNT,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Account)
  })
_sym_db.RegisterMessage(Account)
_sym_db.RegisterMessage(Account.AssociatedKey)
_sym_db.RegisterMessage(Account.ActionThresholds)
_sym_db.RegisterMessage(Account.AccountActivity)

Unit = _reflection.GeneratedProtocolMessageType('Unit', (_message.Message,), {
  'DESCRIPTOR' : _UNIT,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Unit)
  })
_sym_db.RegisterMessage(Unit)

ProtocolVersion = _reflection.GeneratedProtocolMessageType('ProtocolVersion', (_message.Message,), {
  'DESCRIPTOR' : _PROTOCOLVERSION,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.ProtocolVersion)
  })
_sym_db.RegisterMessage(ProtocolVersion)


# @@protoc_insertion_point(module_scope)
